import request from '@/config/axios'

// 地区 VO
export interface AreaVO {
  id: number // id
  name: string // 区域名称
  type: number // 区域类型
  parentId: number // 上级区域
}

// 地区 API
export const AreaApi = {
  // 查询地区列表
  getAreaList: async (params) => {
    return await request.get({ url: `/menduner/system/area/list`, params })
  },

  // 查询地区详情
  getArea: async (id: number) => {
    return await request.get({ url: `/menduner/system/area/get?id=` + id })
  },

  // 新增地区
  createArea: async (data: AreaVO) => {
    return await request.post({ url: `/menduner/system/area/create`, data })
  },

  // 修改地区
  updateArea: async (data: AreaVO) => {
    return await request.put({ url: `/menduner/system/area/update`, data })
  },

  // 删除地区
  deleteArea: async (id: number) => {
    return await request.delete({ url: `/menduner/system/area/delete?id=` + id })
  },

  // 导出地区 Excel
  exportArea: async (params) => {
    return await request.download({ url: `/menduner/system/area/export-excel`, params })
  }
}
