import request from '@/config/axios'

// 门墩儿-角色信息 VO
export interface MdeRoleVO {
  id: number // 角色ID
  name: string // 角色名称
  code: string // 角色权限字符串
  sort: number // 显示顺序
  dataScope: number // 数据范围（1：全部数据权限 2：自定数据权限 3：本企业数据权限 4：本企业及以下数据权限）
  dataScopeDeptIds: string // 数据范围(指定企业数组)
  status: number // 角色状态（0正常 1停用）
  type: number // 角色类型
  remark: string // 备注
}

// 门墩儿-角色信息 API
export const MdeRoleApi = {
  // 查询门墩儿-角色信息分页
  getMdeRolePage: async (params: any) => {
    return await request.get({ url: `/menduner/system/mde-role/page`, params })
  },

  // 查询门墩儿-角色信息详情
  getMdeRole: async (id: number) => {
    return await request.get({ url: `/menduner/system/mde-role/get?id=` + id })
  },

  // 新增门墩儿-角色信息
  createMdeRole: async (data: MdeRoleVO) => {
    return await request.post({ url: `/menduner/system/mde-role/create`, data })
  },

  // 修改门墩儿-角色信息
  updateMdeRole: async (data: MdeRoleVO) => {
    return await request.put({ url: `/menduner/system/mde-role/update`, data })
  },

  // 删除门墩儿-角色信息
  deleteMdeRole: async (id: number) => {
    return await request.delete({ url: `/menduner/system/mde-role/delete?id=` + id })
  },

  // 导出门墩儿-角色信息 Excel
  exportMdeRole: async (params) => {
    return await request.download({ url: `/menduner/system/mde-role/export-excel`, params })
  }
}