import request from '@/config/axios'

// 职业技能 VO
export interface SkillVO {
  id: number // id
  nameCn: string // 技能中文名称
  nameEn: string // 技能英文名称
  parentId: number // 上级id
  level: boolean // 层级
}

// 职业技能 API
export const SkillApi = {
  // 查询职业技能列表
  getSkillList: async (params) => {
    return await request.get({ url: `/menduner/system/skill/list`, params })
  },

  // 查询职业技能详情
  getSkill: async (id: number) => {
    return await request.get({ url: `/menduner/system/skill/get?id=` + id })
  },

  // 新增职业技能
  createSkill: async (data: SkillVO) => {
    return await request.post({ url: `/menduner/system/skill/create`, data })
  },

  // 修改职业技能
  updateSkill: async (data: SkillVO) => {
    return await request.put({ url: `/menduner/system/skill/update`, data })
  },

  // 删除职业技能
  deleteSkill: async (id: number) => {
    return await request.delete({ url: `/menduner/system/skill/delete?id=` + id })
  },

  // 导出职业技能 Excel
  exportSkill: async (params) => {
    return await request.download({ url: `/menduner/system/skill/export-excel`, params })
  }
}